@@ -6,5 +6,7 @@ from .shift import *
 from .inject_transit import *
 from .inject_systematics import *
 from .inject_noise import *
+from .inject_spectrum import *
 from .fold import *
 from .compare import *
+from .remove_trends import *
