@@ -7,6 +7,10 @@ from .rainbow_npy import *
 from .rainbow_FITS import *
 from .text import *
 
+from .xarray_stellar_spectra import *
+from .xarray_raw_light_curves import *
+from .xarray_fitted_light_curves import *
+
 # some particular instruments
 from .nres import *
 from .atoca import *
@@ -16,7 +20,7 @@ from .espinoza import *
 from .dossantos import *
 from .feinstein import *
 from .schlawin import *
-from .coloumbe import *
+from .coulombe import *
 
 
 # construct a dictionary of available readers
@@ -55,6 +59,15 @@ def guess_reader(filepath, format=None):
         return from_rainbow_npy
     elif fnmatch(f.lower(), "*.rainbow.fits") or fnmatch(f.lower(), "*.rainbow.fit"):
         return from_rainbow_FITS
+    # does it look like an ERS-xarray format?
+    elif fnmatch(f, "*stellar-spec*.xc"):
+        return from_xarray_stellar_spectra
+    # does it look like an ERS-xarray format?
+    elif fnmatch(f, "*raw-light-curve*.xc"):
+        return from_xarray_raw_light_curves
+    # does it look like an ERS-xarray format?
+    elif fnmatch(f, "*fitted-light-curve*.xc"):
+        return from_xarray_fitted_light_curves
     # does it look like a .rainbow.npy chromatic file?
     elif fnmatch(f, "*order*.npy"):
         return from_espinoza
@@ -63,7 +76,7 @@ def guess_reader(filepath, format=None):
         return from_x1dints
     # does it look like an Eureka! S3 text file?
     elif fnmatch(f, "*S3_*_Save.dat") or fnmatch(f, "*S3_*_Save.txt"):
-        return from_eureka_SpecData
+        return from_eureka_S3_txt
     # does it look like an Eureka! S3 SpecData hdf5 file?
     elif fnmatch(f, "*S3_*_SpecData.h5"):
         return from_eureka_S3
@@ -75,9 +88,17 @@ def guess_reader(filepath, format=None):
         return from_eureka_S4
     elif fnmatch(f, "*S5_*_Table_Save_*.txt"):
         return from_eureka_S5
+    elif fnmatch(f, "*extract1dstep.fits"):
+        return from_atoca
     elif fnmatch(f, "*.txt") or fnmatch(f, "*.csv"):
         return from_text
     elif fnmatch(f, "*e92-1d.fits") or fnmatch(f, "*e92-1d.fits.fz"):
         return from_nres
     else:
-        raise RuntimeError(f"🌈 Failed to guess a good reader for {filenames}.")
+        raise ValueError(
+            f"""
+        We're having trouble guessing the input format from the filename
+        {f}
+        Please try specifying a `format=` keyword to your call.
+        """
+        )
