@@ -8,3 +8,5 @@ from .plot_spectra import *
 from .plot import *
 from .utilities import *
 from .pcolormesh import *
+from .plot_noise_comparison import *
+from .models import *
