@@ -9,11 +9,12 @@ def plot_spectra(
     ax=None,
     spacing=0.1,
     w_unit="micron",
-    t_unit="hour",
+    t_unit="day",
     cmap=None,
     vmin=None,
     vmax=None,
     errorbar=False,
+    text=True,
     minimum_acceptable_ok=1,
     scatterkw={},
     errorbarkw={},
@@ -44,6 +45,8 @@ def plot_spectra(
         The maximum value to use for the wavelength colormap.
     errorbar : boolean
         Should we plot errorbars?
+    text : boolean
+        Should we label each spectrum?
     minimum_acceptable_ok : float
         The smallest value of `ok` that will still be included.
         (1 for perfect data, 1e-10 for everything but terrible data, 0 for all data)
@@ -108,7 +111,7 @@ def plot_spectra(
         try:
             spacing = ax._most_recent_chromatic_plot_spacing
         except AttributeError:
-            spacing = 3 * np.nanstd(self.flux)
+            spacing = 3 * np.nanstd(self.get(quantity))
     ax._most_recent_chromatic_plot_spacing = spacing
 
     # TO-DO: check if this Rainbow has been normalized
@@ -124,7 +127,7 @@ def plot_spectra(
         for i, t in enumerate(self.time):
             # grab the spectrum for this particular time
             w, y, sigma = self.get_ok_data_for_time(
-                i, minimum_acceptable_ok=minimum_acceptable_ok
+                i, minimum_acceptable_ok=minimum_acceptable_ok, y=quantity
             )
             if np.any(np.isfinite(y)):
 
@@ -167,13 +170,15 @@ def plot_spectra(
                 plt.scatter(plot_x, plot_y, **this_scatterkw)
 
                 # add text labels next to each spectrum
-                this_textkw = dict(va="bottom", color=default_color)
+                this_textkw = dict(va="center", color=default_color)
                 this_textkw.update(**textkw)
-                plt.annotate(
-                    f"{t.to_value(t_unit):.2f} {t_unit.to_string('latex_inline')}",
-                    (min_wave, np.median(plot_y) - 0.5 * spacing),
-                    **this_textkw,
-                )
+                if text:
+                    plt.text(
+                        min_wave,
+                        np.median(plot_y) - 0.5 * spacing,
+                        f"{t.to_value(t_unit):.2f} {t_unit.to_string('latex_inline')}",
+                        **this_textkw,
+                    )
 
         # add text labels to the plot
         plt.xlabel(f"Wavelength ({w_unit.to_string('latex_inline')})")
